@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # BioSTEAM: The Biorefinery Simulation and Techno-Economic Analysis Modules
-# Copyright (C) 2020, Yoel Cortes-Pena <yoelcortes@gmail.com>
+# Copyright (C) 2020-2021, Yoel Cortes-Pena <yoelcortes@gmail.com>
 # 
 # This module is under the UIUC open-source license. See 
 # github.com/BioSTEAMDevelopmentGroup/biosteam/blob/master/LICENSE.txt
@@ -10,7 +10,7 @@
 from . import equilibrium as eq
 from ._chemical import Chemical
 from ._chemicals import Chemicals
-from .mixture import Mixture, ideal_mixture
+from .mixture import Mixture
 from .utils import read_only, cucumber
 
 __all__ = ('Thermo',)
@@ -36,6 +36,8 @@ class Thermo:
         Class for computing poynting correction factors.
     cache : optional
         Whether or not to use cached chemicals.
+    skip_checks : bool, optional
+        Whether to skip checks for missing or invalid properties.
     
     Examples
     --------
@@ -44,12 +46,12 @@ class Thermo:
     >>> import thermosteam as tmo
     >>> thermo = tmo.Thermo(['Ethanol', 'Water'], cache=True)
     >>> thermo
-    Thermo(chemicals=CompiledChemicals([Ethanol, Water]), mixture=Mixture(rule='ideal mixing', ..., include_excess_energies=False), Gamma=DortmundActivityCoefficients, Phi=IdealFugacityCoefficients, PCF=IdealPoyintingCorrectionFactors)
+    Thermo(chemicals=CompiledChemicals([Ethanol, Water]), mixture=Mixture(rule='ideal', ..., include_excess_energies=False), Gamma=DortmundActivityCoefficients, Phi=IdealFugacityCoefficients, PCF=IdealPoyintingCorrectionFactors)
     >>> thermo.show() # May be easier to read
     Thermo(
         chemicals=CompiledChemicals([Ethanol, Water]),
         mixture=Mixture(
-            rule='ideal mixing', ...
+            rule='ideal', ...
             include_excess_energies=False
         ),
         Gamma=DortmundActivityCoefficients,
@@ -66,7 +68,7 @@ class Thermo:
     Thermo(
         chemicals=CompiledChemicals([Ethanol, Water]),
         mixture=Mixture(
-            rule='ideal mixing', ...
+            rule='ideal', ...
             include_excess_energies=False
         ),
         Gamma=IdealActivityCoefficients,
@@ -105,7 +107,7 @@ class Thermo:
     Thermo(
         chemicals=CompiledChemicals([Ethanol, Water]),
         mixture=Mixture(
-            rule='ideal mixing', ...
+            rule='ideal', ...
             include_excess_energies=False
         ),
         Gamma=DortmundActivityCoefficients,
@@ -133,13 +135,14 @@ class Thermo:
                  Gamma=eq.DortmundActivityCoefficients,
                  Phi=eq.IdealFugacityCoefficients,
                  PCF=eq.IdealPoyintingCorrectionFactors,
-                 cache=None):
+                 cache=None,
+                 skip_checks=False):
         if not isinstance(chemicals, Chemicals): chemicals = Chemicals(chemicals, cache)
         if not mixture:
-            mixture = ideal_mixture(chemicals)
+            mixture = Mixture.from_chemicals(chemicals)
         elif not isinstance(mixture, Mixture): # pragma: no cover
             raise ValueError(f"mixture must be a '{Mixture.__name__}' object")
-        chemicals.compile()
+        chemicals.compile(skip_checks=skip_checks)
         issubtype = issubclass
         if not issubtype(Gamma, eq.ActivityCoefficients): # pragma: no cover
             raise ValueError(f"Gamma must be a '{eq.ActivityCoefficients.__name__}' subclass")
@@ -214,7 +217,7 @@ class Thermo:
         Thermo(
             chemicals=CompiledChemicals([Water]),
             mixture=Mixture(
-                rule='ideal mixing', ...
+                rule='ideal', ...
                 include_excess_energies=False
             ),
             Gamma=DortmundActivityCoefficients,
