@@ -15,57 +15,142 @@
 # https://github.com/CalebBell/thermo/blob/master/LICENSE.txt for details.
 """
 """
+import numpy as np
 import flexsolve as flx
 
-__all__ = ('phase_fraction', 'solve_phase_fraction',
-           'compute_phase_fraction_2N', 'compute_phase_fraction_3N')
+__all__ = ('phase_fraction', 
+           'solve_phase_fraction_Rashford_Rice',
+           'solve_phase_fraction_iteration',
+           'phase_composition',
+           'compute_phase_fraction_2N', 
+           'compute_phase_fraction_3N')
 
 @flx.njitable(cache=True)
 def as_valid_fraction(x):
+    """Ensure that x is between 0 and 1."""
     if x < 0.:
         x = 0.
     elif x > 1.:
         x = 1.
     return x
 
-def phase_fraction(zs, Ks, guess=None):
-    """Return phase fraction for binary equilibrium."""
+def phase_fraction(zs, Ks, guess=None, za=0., zb=0.):
+    """Return phase fraction for binary phase equilibrium."""
     N = zs.size
-    if N == 2:
+    if za or zb or N > 3:
+        phase_fraction = solve_phase_fraction_Rashford_Rice(zs, Ks, guess, za, zb)
+    elif N == 2:
         phase_fraction = compute_phase_fraction_2N(zs, Ks)
     elif N == 3:
         phase_fraction = compute_phase_fraction_3N(zs, Ks)
     else:
-        phase_fraction = solve_phase_fraction(zs, Ks, guess)
+        raise ValueError('number of chemicals in equilibrium must be 2 or more '
+                         'to find phase fraction')
     return as_valid_fraction(phase_fraction)
 
-def solve_phase_fraction(zs, Ks, guess):
+def solve_phase_fraction_iteration(zs, Ks, guess=0.5, za=0., zb=0.):
     """
-    Return phase fraction for N-component binary equilibrium through
-    numerically solving an objective function.
+    Return phase fraction for N-component binary phase equilibrium by 
+    accelerated fixed-point iteration. 
+    
+    Notes
+    -----
+    This iterative method was developed by Yoel Cortes-Pena. It can handle 
+    chemicals which do not partition. za and zb are the fraction of 
+    non-partitioning chemicals in phases a and b, respectively. 
+    
+    Examples
+    --------
+    Find the vapor fraction of a mixture of CO2, air, and water. Assume that 
+    air is always a gas, water is always a liquid, but CO2 can partition in both.
+        
+    >>> import numpy as np
+    >>> from thermosteam.equilibrium import (
+    ...     solve_phase_fraction_iteration,
+    ...     phase_composition,
+    ... )
+    >>> F_air = 1
+    >>> F_water = 1
+    >>> F_CO2 = 1
+    >>> F_total = F_air + F_water + F_CO2
+    >>> z_air = F_air / F_total
+    >>> z_water = F_water / F_total
+    >>> zs = np.array([0.333]) # CO2
+    >>> Ks = np.array([0.999]) # CO2
+    >>> phi = solve_phase_fraction_iteration(
+    ...     zs, Ks, za=z_air, zb=z_water
+    ... )
+    >>> phi
+    0.4998
+    
     """
-    args = (zs, Ks)
-    f = phase_fraction_objective_function
-    if Ks.max() < 1.0: return 0.
-    if Ks.min() > 1.0: return 1.
-    y0 = f(0., *args)
-    y1 = f(1., *args)
+    if Ks.max() < 1.0 and not za: return 0.
+    if Ks.min() > 1.0 and not zb: return 1.
+    args = (zs, Ks, za, zb)
+    x0 = 0.
+    x1 = 1.
+    f = compute_phase_fraction_iter
+    y0 = -np.inf if za else f(x0, *args) 
+    y1 = np.inf if zb else f(x1, *args)
     if y0 > y1 > 0.: return 1
     if y1 > y0 > 0.: return 0.
     if y0 < y1 < 0.: return 1.
     if y1 < y0 < 0.: return 0.
-    return flx.IQ_interpolation(f, 0., 1., y0, y1,
+    zs = zs[np.newaxis, :]
+    if not 0. < guess < 1.: guess = 0.5
+    phi = np.ones([2, 1]); phi[:, 0] = [guess, 1. - guess]
+    zc = np.ones([2, 1]); zc[:, 0] = [za, zb]
+    Ks = np.array([Ks, 1. / Ks])
+    phi = flx.wegstein(f, phi, 1e-16, 
+                       args=(zs, Ks, zc), checkiter=False)
+    return phi[0, 0] / phi.sum()
+
+@flx.njitable(cache=True)
+def phase_composition(zs, Ks, phi):
+    return zs * Ks / (phi * Ks + (1. - phi))
+
+@flx.njitable(cache=True)
+def compute_phase_fraction_iter(phi, zs, Ks, zc):
+    ys = phase_composition(zs, Ks, phi)
+    phi = (ys * phi).sum(axis=1, keepdims=True)
+    phi += zc
+    return phi
+    
+def solve_phase_fraction_Rashford_Rice(zs, Ks, guess, za, zb):
+    """
+    Return phase fraction for N-component binary equilibrium by
+    numerically solving the Rashford Rice equation.
+    
+    """
+    if Ks.max() < 1.0 and not za: return 0.
+    if Ks.min() > 1.0 and not zb: return 1.
+    K_minus_1 = Ks - 1.
+    args = (zs, K_minus_1, za, zb)
+    f = phase_fraction_objective_function
+    x0 = 0.
+    x1 = 1.
+    y0 = -np.inf if za else f(x0, *args) 
+    y1 = np.inf if zb else f(x1, *args)
+    if y0 > y1 > 0.: return 1
+    if y1 > y0 > 0.: return 0.
+    if y0 < y1 < 0.: return 1.
+    if y1 < y0 < 0.: return 0.
+    x0, x1, y0, y1 = flx.find_bracket(f, x0, x1, y0, y1, args, tol=5e-8)
+    if abs(x1 - x0) < 1e-6: return (x0 + x1) / 2.
+    return flx.IQ_interpolation(f, x0, x1, y0, y1,
                                 guess, 1e-16, 1e-16,
                                 args, checkiter=False)
 
 @flx.njitable(cache=True)
-def phase_fraction_objective_function(V, zs, Ks):
+def phase_fraction_objective_function(phi, zs, K_minus_1, za, zb):
     """Phase fraction objective function."""
-    Kterm = Ks - 1.
-    numerator = zs * Kterm
-    denominator = 1. + V * Kterm
+    numerator = - zs * K_minus_1
+    denominator = 1. + phi * K_minus_1
     denominator[denominator < 1e-16] = 1e-16
-    return (numerator / denominator).sum()    
+    a = za/phi if za > 0. else 0.
+    b = zb/(1. - phi) if zb > 0. else 0.
+    phi = (numerator / denominator).sum()
+    return phi - a + b
 
 @flx.njitable(cache=True)
 def compute_phase_fraction_2N(zs, Ks):
@@ -198,9 +283,9 @@ def compute_phase_fraction_3N(zs, Ks):
     K22K32z2z3 = K22K32*z2z3
     K22K32z32 = K22K32*z32
     return ((-K1K2z1/2 - K1K2z2/2 - K1K3z1/2 - K1K3z3/2 + K1z1
-             + K1z2/2 + K1z3/2 - K2K3z2/2 - K2K3z3/2 + K2z1/2 + K2z2
-             + K2z3/2 + K3z1/2 + K3z2/2 + K3z3 - z1_z2_z3
-             - (K12K22z12 + 2*K12K22z1z2 + K12K22z22
+              + K1z2/2 + K1z3/2 - K2K3z2/2 - K2K3z3/2 + K2z1/2 + K2z2
+              + K2z3/2 + K3z1/2 + K3z2/2 + K3z3 - z1_z2_z3
+              - (K12K22z12 + 2*K12K22z1z2 + K12K22z22
                 - 2*K12K2K3z12 - 2*K12K2K3z1z2 - 2*K12K2K3z1z3
                 + 2*K12K2K3z2z3 - 2*K12K2z1z2 + 2*K12K2z1z3
                 - 2*K12K2z22 - 2*K12K2z2z3 + K12K32z12
@@ -224,6 +309,6 @@ def compute_phase_fraction_3N(zs, Ks):
                 - 2*K2K3*z12 - 2*K2K3*z1z2 - 2*K2K3*z1z3
                 + 2*K2K3*z2z3 + K32*z12 + 2*K32*z1z2 + K32*z22)**0.5/2)
                 / (K1K2K3*z1 + K1K2K3*z2 + K1K2K3*z3 - K1K2*z1 - K1K2*z2
-                   - K1K2*z3 - K1K3*z1 - K1K3*z2 - K1K3*z3 + K1z1 + K1z2
-                   + K1z3 - K2K3*z1 - K2K3*z2 - K2K3*z3 + K2z1 + K2z2 + K2z3
-                   + K3z1 + K3z2 + K3z3 - z1_z2_z3))
\ No newline at end of file
+                    - K1K2*z3 - K1K3*z1 - K1K3*z2 - K1K3*z3 + K1z1 + K1z2
+                    + K1z3 - K2K3*z1 - K2K3*z2 - K2K3*z3 + K2z1 + K2z2 + K2z3
+                    + K3z1 + K3z2 + K3z3 - z1_z2_z3))
\ No newline at end of file
